\name{fpAnova}
\alias{fpAnova}
\title{
Function to perform ANOVA on fp objects
}
\description{
This function computes Bayes Factors and p-values for within-subjects ANOVA designs, encoded as fp objects.}
\usage{
fpAnova(object, stat = "BF", na.rm = TRUE)
}
\arguments{
  \item{object}{
a list of objects from class fp1.
}
  \item{stat}{
Either "BF" (default), "p", or "both", specificying what statistic to report.
}
  \item{na.rm}{
Are \code{NA}s removed?
}
}
\details{
The function expects the output of \code{fpGet}, but in a list. 
}
\value{
A list containing the results of either the Bayesian or frequentist analysis, or both:

\item{BF }{The output of \code{anovaBF}}
\item{p }{The output of \code{summary.aov}}
}
\references{
Van Maanen, L. & Van Rijn, H (submitted). The fixed-point property in concurrent processing. Manuscript submitted for publication
}
\author{
Leendert van Maanen  (l.vanmaanen@uva.nl)}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{fpGet}}, \code{\link{anovaBF}}, \code{\link{summary.aov}}.
}
\examples{
## generate data
p <- c(.1,.5,.9)
rt <- sapply(1:3, function(i) {rnormMix(10000, c(1,2), c(1,1), p[i])})
dat <- data.frame(rt=c(rt), cond=rep(1:3, each=10000), pp=rep(1:50, each=200, times=3))

## compute the list of fp1 objects
res <- tapply(1:nrow(dat), dat$pp, function(X) {fpGet(dat[X,], 1000, bw=.75)})

## call fpAnova, with stat="both" to do both a Bayesian and a frequentist test
fpAnova(res, stat="both")
}