\name{fpPlot}
\alias{fpPlot}
\alias{plot.fp1}
\title{
Function to plot the distributions and differences of multiple binary mixture distributions.
}
\description{
This function plots kernel-based densities as well as density differences for three or more data sets (fp1 objects). 
}
\usage{
## S3 method for class fp1
plot(x, ..., ylab = c("Density", "Density difference"), xlim = NULL)
fpPlot(x, ..., ylab = c("Density", "Density difference"), xlim = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
an fp1 object
}
  \item{ylab}{
y-axis labels of the two plots
}
  \item{xlim}{
the x limits (x1, x2) of the two plots
}
  \item{\dots}{
additional arguments to pass to both plot.density() and matplot ()
}
}
\references{
Van Maanen, L. & Van Rijn, H (submitted). The fixed-point property in concurrent processing. Manuscript submitted for publication
}
\author{
Leendert van Maanen (l.vanmaanen@uva.nl)
}

\seealso{
\code{\link{fpGet}},\code{\link{fpDensDiff}},\code{\link{plot.density}},\code{\link{matplot}}
}
\examples{
## generate data
p <- c(.1,.5,.9)
rt <- sapply(1:3, function(i) {rnormMix(1000, c(1,2), c(1,1), p[i])})
dat <- data.frame(rt=c(rt), cond=rep(1:3, each=1000))

## compute fp1 object
fpobject <- fpGet(dat, 1000, bw=.75)

## plot it
par(mfrow=c(1,2))
plot(fpobject)

## alternatives
plot.fp1(fpobject)
fpPlot(fpobject)

}
